==> spip_3.2.11.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_vi.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=vi
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// I
	'icone_evolution_visites' => 'Thống kê<br />@visites@ độc giả',
	'icone_repartition_actuelle' => 'Cho xem phân loại hiện nay',
	'icone_repartition_visites' => 'Phân bố số thăm viếng',
	'icone_statistiques_visites' => 'Thống kê',
	'info_affichier_visites_articles_plus_visites' => 'Cho thấy số lần vào xem của <b>những bài được đọc nhiều nhất từ ban đầu:</b>',
	'info_comment_lire_tableau' => 'Cách đọc đồ thị này',
	'info_forum_statistiques' => 'Thống kê thăm viếng',
	'info_popularite_2' => 'Mức phổ thông của website: ',
	'info_popularite_3' => 'Mức phổ thông: @popularite@; lần viếng: @visites@',
	'info_popularite_5' => ' phổ thông:',
	'info_visites' => ' thăm viếng:',
	'info_visites_plus_populaires' => 'Cho thấy số lần vào xem của <b>những bài được chuộng nhất</b> và của <b>những bài đăng tải sau cùng:</b>',
	'info_zoom' => 'phóng lớn',
	'item_gerer_statistiques' => 'Quản trị số thống kê', # MODIF

	// O
	'onglet_origine_visites' => 'Xuất xứ của thăm viếng',
	'onglet_repartition_debut' => 'từ ban đầu',
	'onglet_repartition_lang' => 'Phổ biến theo ngôn ngữ',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_comment_lire_tableau' => 'Bài vở được sắp hạng theo mức độ phổ thông (xem cột trái). Để xem mức độ phổ thông (ước lượng số lần vào xem hàng ngày theo đà hiện tại) và số lần vào xem của mỗi bài, bạn di chuyển con chuột lên trên tên bài.',
	'texte_signification' => 'Thanh đậm biểu hiện tất cả số bài (tổng cộng của các đề mục phụ), thanh lợt biểu hiện số lần vào xem của mỗi đề mục. ',
	'titre_evolution_visite' => 'Thống Kê',
	'titre_liens_entrants' => 'Các điểm nối vào',
	'titre_page_statistiques' => 'Thống kê theo từng đề mục',
	'titre_page_statistiques_visites' => 'Thống kê về thăm viếng'
);

==> spip_4.4.3+dfsg.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_vi.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=vi
// ** ne pas modifier le fichier **

return [

	// I
	'icone_evolution_visites' => 'Thống kê<br />@visites@ độc giả',
	'icone_repartition_actuelle' => 'Cho xem phân loại hiện nay',
	'icone_repartition_visites' => 'Phân bố số thăm viếng',
	'icone_statistiques_visites' => 'Thống kê',
	'info_affichier_visites_articles_plus_visites' => 'Cho thấy số lần vào xem của <b>những bài được đọc nhiều nhất từ ban đầu:</b>',
	'info_comment_lire_tableau' => 'Cách đọc đồ thị này',
	'info_forum_statistiques' => 'Thống kê thăm viếng',
	'info_popularite_2' => 'Mức phổ thông của website: ',
	'info_popularite_3' => 'Mức phổ thông: @popularite@; lần viếng: @visites@',
	'info_popularite_5' => ' phổ thông:',
	'info_visites' => ' thăm viếng:',
	'info_visites_plus_populaires' => 'Cho thấy số lần vào xem của <b>những bài được chuộng nhất</b> và của <b>những bài đăng tải sau cùng:</b>',
	'info_zoom' => 'phóng lớn',
	'item_gerer_statistiques' => 'Quản trị số thống kê', # MODIF

	// O
	'onglet_origine_visites' => 'Xuất xứ của thăm viếng',
	'onglet_repartition_debut' => 'từ ban đầu',
	'onglet_repartition_lang' => 'Phổ biến theo ngôn ngữ',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_comment_lire_tableau' => 'Bài vở được sắp hạng theo mức độ phổ thông (xem cột trái). Để xem mức độ phổ thông (ước lượng số lần vào xem hàng ngày theo đà hiện tại) và số lần vào xem của mỗi bài, bạn di chuyển con chuột lên trên tên bài.',
	'texte_signification' => 'Thanh đậm biểu hiện tất cả số bài (tổng cộng của các đề mục phụ), thanh lợt biểu hiện số lần vào xem của mỗi đề mục. ',
	'titre_evolution_visite' => 'Thống Kê',
	'titre_liens_entrants' => 'Các điểm nối vào',
	'titre_page_statistiques' => 'Thống kê theo từng đề mục',
	'titre_page_statistiques_visites' => 'Thống kê về thăm viếng',
];
